# jumpstarter-python

This project provides both a library, and a command line client to interact with the
Jumpstarter resources and services.

For more details see the following documents:

* [Glossary](docs/glossary.md)
* [Usage](docs/usage.md)
* [Architecture](docs/architecture.md)